aboutsummaryrefslogtreecommitdiff
path: root/reloc_win32.h
diff options
context:
space:
mode:
Diffstat (limited to 'reloc_win32.h')
-rw-r--r--reloc_win32.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/reloc_win32.h b/reloc_win32.h
index 207c6e7..6393702 100644
--- a/reloc_win32.h
+++ b/reloc_win32.h
@@ -10,11 +10,11 @@
#include <vector>
-#include "base/optional.h"
#include "components/zucchini/address_translator.h"
#include "components/zucchini/buffer_source.h"
#include "components/zucchini/buffer_view.h"
#include "components/zucchini/image_utils.h"
+#include "third_party/abseil-cpp/absl/types/optional.h"
namespace zucchini {
@@ -65,9 +65,9 @@ class RelocRvaReaderWin32 {
RelocRvaReaderWin32(RelocRvaReaderWin32&&);
~RelocRvaReaderWin32();
// Successively visits and returns data for each reloc unit, or base::nullopt
// when all reloc units are found. Encapsulates block transition details.
- base::Optional<RelocUnitWin32> GetNext();
+ absl::optional<RelocUnitWin32> GetNext();
private:
// Assuming that |block_begin| points to the beginning of a reloc block, loads
@@ -102,7 +102,7 @@ class RelocReaderWin32 : public ReferenceReader {
~RelocReaderWin32() override;
// ReferenceReader:
- base::Optional<Reference> GetNext() override;
+ absl::optional<Reference> GetNext() override;
private:
RelocRvaReaderWin32 reloc_rva_reader_;
@@ -65,9 +65,9 @@ class RelocRvaReaderWin32 {
RelocRvaReaderWin32(RelocRvaReaderWin32&&);
~RelocRvaReaderWin32();
- // Successively visits and returns data for each reloc unit, or base::nullopt
+ // Successively visits and returns data for each reloc unit, or absl::nullopt
// when all reloc units are found. Encapsulates block transition details.